@@ -27,7 +27,8 @@ sce <- SingleCellExperiment(
 SDDLS <- createSpatialDDLSobject(
   sc.data = sce,
   sc.cell.ID.column = "Cell_ID",
-  sc.gene.ID.column = "Gene_ID"
+  sc.gene.ID.column = "Gene_ID",
+  sc.filt.genes.cluster = FALSE
 )
 SDDLS <- genMixedCellProp(
   object = SDDLS,
@@ -54,8 +55,8 @@ SDDLS <- simSCProfiles(
 # simulating spatial data
 simSpatialExperiment <- function(n = 1) {
   sim.samples <- function() {
-    ngenes <- sample(3:40, size = 1)
-    ncells <- sample(3:40, size = 1)
+    ngenes <- sample(5:40, size = 1)
+    ncells <- sample(5:40, size = 1)
     counts <- matrix(
       rpois(ngenes * ncells, lambda = 5), ncol = ncells,
       dimnames = list(paste0("Gene", seq(ngenes)), paste0("Spot", seq(ncells)))
@@ -81,7 +82,7 @@ test_that(
   {
     # object without prob.cell.types slot
     expect_error(
-      trainDeconvModel(object = SDDLS, verbose = FALSE), 
+      trainDeconvModel(object = SDDLS, num.epochs = 10, verbose = FALSE), 
       regexp = "If `type.data.train` = mixed is selected, 'mixed.profiles' must be provided"
     )
     SDDLS <- suppressWarnings(
@@ -96,21 +97,23 @@ test_that(
     # combine = 'both' without mixed samples
     expect_error(
       trainDeconvModel(
-        object = SDDLS, type.data.train = "both", verbose = FALSE
+        object = SDDLS, type.data.train = "both", 
+        num.epochs = 10, verbose = FALSE
       ), 
       regexp = "If `type.data.train` = both'"
     )
     expect_error(
       trainDeconvModel(
         object = SDDLS, type.data.train = "single-cell", 
-        type.data.test = "both", verbose = FALSE
+        num.epochs = 10, type.data.test = "both", verbose = FALSE
       ), 
       regexp = "If `type.data.test` = both' is selected, 'mixed.profiles' and at least one single cell slot must be provided"
     )
     # combine = 'mixed' without mixed samples
     expect_error(
       trainDeconvModel(
-        object = SDDLS, type.data.train = "mixed", verbose = FALSE
+        object = SDDLS, type.data.train = "mixed", 
+        num.epochs = 10, verbose = FALSE
       ), 
       regexp = "If `type.data.train` = mixed is selected, 'mixed.profiles' must be provided"
     )
@@ -129,6 +132,7 @@ test_that(
           type.data.train = "single-cell",
           on.the.fly = TRUE,
           batch.size = 12,
+          num.epochs = 10, 
           view.metrics.plot = FALSE
         )
       ),
@@ -144,6 +148,7 @@ test_that(
           object = SDDLSBad,
           type.data.train = "mixed",
           on.the.fly = TRUE,
+          num.epochs = 10, 
           batch.size = 12,
           view.metrics.plot = FALSE
         )
@@ -156,6 +161,7 @@ test_that(
         object = SDDLS,
         on.the.fly = TRUE,
         agg.function = "Invalid",
+        num.epochs = 10, 
         batch.size = 12,
         view.metrics.plot = FALSE
       ), 
@@ -183,7 +189,8 @@ test_that(
         object = SDDLS,
         num.hidden.layers = 3,
         num.units = c(200, 200, 100),
-        batch.size = 28,
+        num.epochs = 10, 
+        batch.size = 20,
         verbose = FALSE
       )
       expect_true(
@@ -197,7 +204,8 @@ test_that(
         object = SDDLS,
         num.hidden.layers = 1,
         num.units = c(100),
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       )
       expect_false(
@@ -219,7 +227,8 @@ test_that(
           object = SDDLS,
           num.hidden.layers = 1,
           num.units = c(200, 200, 100),
-          batch.size = 28,
+          batch.size = 20,
+          num.epochs = 10, 
           verbose = FALSE
         ),
         regexp = "The number of hidden layers must be equal"
@@ -230,7 +239,8 @@ test_that(
         num.hidden.layers = 1,
         num.units = c(100),
         activation.fun = "elu",
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       )
       expect_true(
@@ -246,7 +256,8 @@ test_that(
         num.hidden.layers = 2,
         num.units = c(100, 100),
         dropout.rate = 0.45,
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       )
       expect_true(
@@ -261,7 +272,8 @@ test_that(
         loss = "mean_squared_error",
         metrics = c("accuracy", "mean_absolute_error",
                     "cosine_similarity"),
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       )
       expect_true(
@@ -274,7 +286,7 @@ test_that(
       expect_error(
         object = trainDeconvModel(
           object = SDDLS,
-          batch.size = 28,
+          batch.size = 20,
           scaling = "invalid",
           verbose = FALSE
         ), 
@@ -282,29 +294,33 @@ test_that(
       )
       # check behaviour
       SDDLS@trained.model <- NULL
-      SDDLS.standarize <- trainDeconvModel(
+      SDDLS.standardize <- trainDeconvModel(
         object = SDDLS,
-        batch.size = 28,
-        scaling = "standarize",
+        batch.size = 20,
+        scaling = "standardize",
+        num.epochs = 10, 
         verbose = FALSE
       )
       SDDLS.rescale <- trainDeconvModel(
         object = SDDLS,
-        batch.size = 28,
+        batch.size = 20,
         scaling = "rescale",
+        num.epochs = 10, 
         verbose = FALSE
       )
-      samp.stand <- as.numeric(gsub(
-        pattern = "Spot_|CellType\\d\\_Simul|RH|C", 
-        replacement = "", 
-        x = rownames(SDDLS.standarize@trained.model@test.pred)
-      )) %>% order()
+      samp.stand <- as.numeric(
+        gsub(
+          pattern = "test_|Spot_|CellType\\d\\_Simul|RH|C", 
+          replacement = "", 
+          x = rownames(SDDLS.standardize@trained.model@test.pred)
+        )
+      ) %>% order()
       samp.rescale <- as.numeric(gsub(
-        pattern = "Spot_|CellType\\d\\_Simul|RH|C", 
+        pattern = "test_|Spot_|CellType\\d\\_Simul|RH|C", 
         replacement = "", 
         x = rownames(SDDLS.rescale@trained.model@test.pred)
       )) %>% order()
-      stand <- SDDLS.standarize@trained.model@test.pred[samp.stand, ]
+      stand <- SDDLS.standardize@trained.model@test.pred[samp.stand, ]
       rescale <- SDDLS.rescale@trained.model@test.pred[samp.rescale, ]
       expect_false(object = all(stand == rescale))
     }
@@ -348,7 +364,8 @@ test_that(
     SDDLS <- trainDeconvModel(
       object = SDDLS, 
       custom.model = customModel,
-      batch.size = 28,
+      batch.size = 20,
+      num.epochs = 10, 
       verbose = FALSE
     )
     expect_s4_class(
@@ -386,7 +403,8 @@ test_that(
       trainDeconvModel(
         object = SDDLS, 
         custom.model = customModel,
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       ), regexp = "The number of neurons of the last layer must be equal"
     )
@@ -415,7 +433,8 @@ test_that(
       trainDeconvModel(
         object = SDDLS, 
         custom.model = customModel,
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       ), regexp = "The number of neurons of the first layer must be equal to the number of genes"
     )
@@ -444,7 +463,8 @@ test_that(
       trainDeconvModel(
         object = SDDLS, 
         custom.model = customModel,
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       ), regexp = "In order to get proportions as output, the activation function of the last hidden layer must be 'softmax'"
     )
@@ -472,7 +492,8 @@ test_that(
     # check is everything works
     SDDLS <- trainDeconvModel(
       object = SDDLS,
-      batch.size = 28,
+      batch.size = 20,
+      num.epochs = 10, 
       verbose = FALSE
     )
     ste <- simSpatialExperiment(n = 1)
@@ -483,13 +504,13 @@ test_that(
       st.gene.ID.column = "Gene_ID",
       st.n.slides = 1
     )
-    SDDLS <- deconvSpatialDDLS(object = SDDLS, index.st = 1)
+    SDDLS <- deconvSpatialDDLS(object = SDDLS, index.st = 1, pca.space = FALSE)
     # expect_true(names(deconv.spots(SDDLS)) == names(spatial.experiments(SDDLS)))
     expect_true(
-      nrow(deconv.spots(SDDLS, 1)) == ncol(spatial.experiments(SDDLS, 1))
+      nrow(deconv.spots(SDDLS, 1)[["Regularized"]]) == ncol(spatial.experiments(SDDLS, 1))
     )
     expect_true(
-      all(rownames(deconv.spots(SDDLS, 1)) == 
+      all(rownames(deconv.spots(SDDLS, 1)[["Regularized"]]) == 
             colnames(spatial.experiments(SDDLS, 1)))
     )
     # index.st does not exist
@@ -497,6 +518,7 @@ test_that(
       deconvSpatialDDLS(
         object = SDDLS, 
         index.st = "not_exists",
+        pca.space = FALSE,
         verbose = FALSE
       ), regexp = "spatial.experiment slot does not contain names, so `index.st` must be an integer"
     )
@@ -506,6 +528,7 @@ test_that(
       deconvSpatialDDLS(
         object = SDDLS,
         index.st = 1,
+        pca.space = FALSE,
         simplify.set = list(c("Mc", "M")),
         verbose = FALSE
       ), 
@@ -515,23 +538,25 @@ test_that(
     SDDLS <- deconvSpatialDDLS(
       object = SDDLS,
       index.st = 1,
+      pca.space = FALSE,
       simplify.set = list(CellTypesNew = c("CellType2", "CellType4")),
       verbose = FALSE
     )
     expect_type(deconv.spots(SDDLS, 1), type = "list")
     expect_identical(names(deconv.spots(SDDLS, 1)), c("raw", "simpli.set"))
     expect_true(
-      any(colnames(deconv.spots(SDDLS, index.st = 1)$simpli.set) == 
+      any(colnames(deconv.spots(SDDLS, index.st = 1)[["simpli.set"]]) == 
             "CellTypesNew")
     )
     expect_false(
-      any(colnames(deconv.spots(SDDLS, index.st = 1)$raw) == 
+      any(colnames(deconv.spots(SDDLS, index.st = 1)[["raw"]][["Regularized"]]) == 
             "CellTypesNew")
     )
     deconv.spots(SDDLS) <- NULL
     SDDLS <- deconvSpatialDDLS(
       object = SDDLS,
       index.st = 1,
+      pca.space = FALSE,
       simplify.set = list(
         CellTypesNew = c("CellType2", "CellType4"), 
         CellTypesNew2 = c("CellType3", "CellType1")
@@ -548,19 +573,20 @@ test_that(
     SDDLS <- deconvSpatialDDLS(
       object = SDDLS,
       index.st = 1,
+      pca.space = FALSE,
       simplify.majority = list(c("CellType2", "CellType4"), 
                                c("CellType3", "CellType1")),
       verbose = FALSE
     )
     expect_true(
       all(colnames(deconv.spots(SDDLS, index.st = 1)$simpli.maj) == 
-            colnames(deconv.spots(SDDLS, index.st = 1)$raw))
+            colnames(deconv.spots(SDDLS, index.st = 1)[["raw"]][["Regularized"]]))
     )
     expect_true(
       all(
         names(which(apply(
           X = deconv.spots(SDDLS, index.st = 1)$simpli.maj != 
-            deconv.spots(SDDLS, index.st = 1)$raw,
+            deconv.spots(SDDLS, index.st = 1)[["raw"]][["Regularized"]],
           MARGIN = 2,
           FUN = sum) > 0)
         ) %in% c("CellType2", "CellType4", "CellType3", "CellType1")
@@ -571,6 +597,7 @@ test_that(
     SDDLS <- deconvSpatialDDLS(
       object = SDDLS,
       index.st = 1,
+      pca.space = FALSE,
       simplify.majority = list(c("CellType2", "CellType4"), 
                                c("CellType3", "CellType1")),
       simplify.set = list(
@@ -584,7 +611,10 @@ test_that(
             c("raw", "simpli.set", "simpli.majority"))
     )
     barPlotCellTypes(
-      data = SDDLS, index.st = 1, colors = default.colors(), simplify = "simpli.majority"
+      data = SDDLS, index.st = 1, colors = default.colors(), set = "simpli.majority"
+    )
+    barPlotCellTypes(
+      data = SDDLS, index.st = 1, colors = default.colors(), set = NULL
     )
     
     ## deconvolution of more than 1 SpatialExperiment object
@@ -596,21 +626,23 @@ test_that(
       st.gene.ID.column = "Gene_ID",
       st.n.slides = 1
     )
-    SDDLS <- deconvSpatialDDLS(object = SDDLS)
+    ## pca.space == FALSE because sometimes var is only explained by 1 PC in fake data
+    SDDLS <- deconvSpatialDDLS(object = SDDLS, pca.space = FALSE) 
     expect_true(
       all(names(deconv.spots(SDDLS)) == names(spatial.experiments(SDDLS)))
     )
     expect_true(
-      nrow(deconv.spots(SDDLS, 4)) == ncol(spatial.experiments(SDDLS, 4))
+      nrow(deconv.spots(SDDLS, 4)[["Regularized"]]) == ncol(spatial.experiments(SDDLS, 4))
     )
     expect_true(
-      all(rownames(deconv.spots(SDDLS, 1)) == 
+      all(rownames(deconv.spots(SDDLS, 1)[["Regularized"]]) == 
             colnames(spatial.experiments(SDDLS, 1)))
     )
     # index.st does not exist
     expect_error(
       deconvSpatialDDLS(
         object = SDDLS, 
+        pca.space = FALSE,
         index.st = "no",
         verbose = FALSE
       ), regexp = "`index.st` contains elements not present in spatial.experiments slot"
@@ -621,6 +653,7 @@ test_that(
       deconvSpatialDDLS(
         object = SDDLS,
         index.st = 1,
+        pca.space = FALSE,
         simplify.set = list(c("Mc", "M")),
         verbose = FALSE
       ), 
@@ -646,7 +679,8 @@ test_that(
     SDDLS <- suppressWarnings(
       trainDeconvModel(
         object = SDDLS,
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       )
     )
@@ -675,7 +709,7 @@ test_that(
       st.n.slides = 1
     )
     SDDLS <- deconvSpatialDDLS(
-      object = SDDLS, index.st = 1, verbose = FALSE
+      object = SDDLS, index.st = 1, verbose = FALSE, pca.space = FALSE
     )
     SDDLSNew <- loadSTProfiles(
       object = SDDLSNew, 
@@ -685,7 +719,7 @@ test_that(
       st.n.slides = 1
     )
     SDDLSNew <- deconvSpatialDDLS(
-      object = SDDLSNew, index.st = 1, verbose = FALSE
+      object = SDDLSNew, index.st = 1, pca.space = FALSE, verbose = FALSE
     )
     expect_true(
       all(colnames(deconv.spots(SDDLSNew, 1)) == 
@@ -726,7 +760,8 @@ test_that(
     SDDLS <- suppressWarnings(
       trainDeconvModel(
         object = SDDLS,
-        batch.size = 28,
+        batch.size = 20,
+        num.epochs = 10, 
         verbose = FALSE
       )
     )
@@ -740,6 +775,7 @@ test_that(
     SDDLS <- deconvSpatialDDLS(
       object = SDDLS,
       index.st = 1,
+      pca.space = FALSE,
       verbose = FALSE
     )
     # index.st not provided
@@ -749,13 +785,14 @@ test_that(
     )
     # No results available 
     expect_error(
-      barPlotCellTypes(data = SDDLS, simplify = "no_res", index.st = 1),
+      barPlotCellTypes(data = SDDLS, set = "no_res", index.st = 1),
       regexp = "No simplified results available"
     )
     # invalid simplify argument 
     SDDLS <- deconvSpatialDDLS(
       object = SDDLS,
       index.st = 1,
+      pca.space = FALSE,
       simplify.set = list(
         CellTypesNew = c("CellType2", "CellType4"), 
         CellTypesNew2 = c("CellType3", "CellType1")
@@ -764,8 +801,8 @@ test_that(
                                c("CellType3", "CellType1"))
     )
     expect_error(
-      barPlotCellTypes(data = SDDLS, simplify = "no_res", index.st = 1),
-      regexp = "simplify argument must be one of the following options: 'simpli.set' or 'simpli.majority'"
+      barPlotCellTypes(data = SDDLS, set = "no_res", index.st = 1),
+      regexp = "set argument must be one of the following options: 'simpli.set' or 'simpli.majority'"
     )
     # not enough colors
     expect_error(
@@ -790,11 +827,11 @@ test_that(
       class = "gg"
     )
     expect_s3_class(
-      barPlotCellTypes(data = SDDLS, simplify = "simpli.set", index.st = 1), 
+      barPlotCellTypes(data = SDDLS, set = "simpli.set", index.st = 1), 
       class = "gg"
     )
     expect_s3_class(
-      barPlotCellTypes(data = SDDLS, simplify = "simpli.majority", index.st = 1), 
+      barPlotCellTypes(data = SDDLS, set = "simpli.majority", index.st = 1), 
       class = "gg"
     )
   }
